#include <LibOrderReliable.mqh>

extern string OrderOptions=    "--------   Orders options  --------";
extern double Lots = 0.05;
extern string     MM_Parameters    = " MoneyManagement by L.Williams ";
extern bool       MM               =   false; //  Switch
extern double     MaxRisk          =    0.01; // Risk Factor
extern double     LossMax          =       0; // Maximum Loss by 1 Lot
extern int TakeProfit = 5;
extern int StopLoss = 14;

int gi_88 = 1;
int g_slippage_92 = 3;
int g_period_96 = 4;
int gi_100 = 2;
extern int Close_Time = 3;
extern int Start_Time = 22;
int gi_unused_124 = 7;
int gi_128 = 4000;
int gi_132 = 7600;
int gi_136 = 0;
double g_ibands_140;
double g_ibands_148;

double gd_unused_180;
double gd_unused_188;
double gd_unused_196;
double g_istochastic_204;
double g_istochastic_212;
double g_price_220;
double gd_unused_228;
double gd_unused_236;
double g_ask_244;
double g_bid_252;
double gd_260;
double gd_268;
int gi_276;

int init() {
   gd_unused_180 = 0;
   gi_276 = 0;
   return (0);
}

double MoneyManagement()
{
   double lot_min =MarketInfo(Symbol(),MODE_MINLOT);
   double lot_max =MarketInfo(Symbol(),MODE_MAXLOT);
   double lot_step=MarketInfo(Symbol(),MODE_LOTSTEP);
   double contract=MarketInfo(Symbol(),MODE_LOTSIZE);
   double vol;
//--- check data
   if(lot_min<0 || lot_max<=0.0 || lot_step<=0.0) 
   {
   Print("CalculateVolume: invalid MarketInfo() results [",lot_min,",",lot_max,",",lot_step,"]");
   return(0);
   }
   if(AccountLeverage()<=0)
   {
   Print("CalculateVolume: invalid AccountLeverage() [",AccountLeverage(),"]");
   return(0);
   }
//--- basic formula
   if ( MM )
   {
   vol=NormalizeDouble(AccountFreeMargin()*MaxRisk*AccountLeverage()/contract,2);
  // Print("Margin=",AccountFreeMargin()," r=",MaxRisk," lev=",AccountLeverage()," cont=",contract);
   }
   else
   vol=Lots;
//--- check min, max and step
   vol=NormalizeDouble(vol/lot_step,0)*lot_step;
   if(vol<lot_min) vol=lot_min;
   if(vol>lot_max) vol=lot_max;
//---
   return(vol);
} 

void start() {
   if (DayOfWeek() == 5 && Hour() == 21 || Hour() == 22) gi_276 = 2;
   if (OrdersTotal() == 0 && gi_276 == 0) CheckForbuyorsell();
   if (OrdersTotal() == 0) gi_276 = 0;
   if (gi_276 == 1 || gi_276 == -1) Pc();
}

void CheckForbuyorsell() {
   g_ibands_140 = iBands(Symbol(), PERIOD_M15, g_period_96, gi_100, 0, PRICE_OPEN, MODE_UPPER, 0);
   g_ibands_148 = iBands(Symbol(), PERIOD_M15, g_period_96, gi_100, 0, PRICE_OPEN, MODE_LOWER, 0);
   g_istochastic_204 = iStochastic(NULL, PERIOD_M15, 8, 5, 5, MODE_SMA, 0, MODE_MAIN, 0);
   g_istochastic_212 = iStochastic(NULL, PERIOD_M15, 8, 5, 5, MODE_SMA, 0, MODE_SIGNAL, 0);
   gd_unused_228 = iStochastic(NULL, PERIOD_H1, 8, 5, 5, MODE_SMA, 0, MODE_MAIN, 0);
   gd_unused_236 = iStochastic(NULL, PERIOD_H1, 8, 5, 5, MODE_SMA, 0, MODE_SIGNAL, 0);
   
   if (Close[0] > g_ibands_140 + gi_88 * Point && g_istochastic_204 < g_istochastic_212 && Hour() < Close_Time || Hour() > Start_Time) {
      OrderSendReliable2Step(Symbol(), OP_SELL, MoneyManagement(), Bid, g_slippage_92, Bid + StopLoss * Point, Bid - TakeProfit * Point - gi_136 * Point, "My order #2", 16384, 3, Green);
      gi_276 = 1;
      gd_unused_188 = g_ibands_140;
      g_price_220 = TimeCurrent();
      g_bid_252 = Bid;
      gd_260 = Bid - TakeProfit * Point;
   }
   if (Close[0] < g_ibands_148 - gi_88 * Point && g_istochastic_204 > g_istochastic_212 && Hour() <= Close_Time || Hour() >= Start_Time) {
      OrderSendReliable2Step(Symbol(), OP_BUY, MoneyManagement(), Ask, g_slippage_92, Ask - StopLoss * Point, Ask + TakeProfit * Point + gi_136 * Point, "My order #2", 16384, 3, Green);
      gi_276 = -1;
      gd_unused_196 = g_ibands_148;
      g_price_220 = TimeCurrent();
      g_ask_244 = Ask;
      gd_268 = Ask + TakeProfit * Point;
   }
}

void Pc() {
   if (gi_276 == -1 && Bid >= gd_268) {
      for (int l_pos_0 = 0; l_pos_0 < OrdersTotal(); l_pos_0++) {
         if (OrderSelect(l_pos_0, SELECT_BY_POS, MODE_TRADES) == FALSE) break;
         if (OrderSymbol() != Symbol()) continue;
         OrderClose(OrderTicket(), OrderLots(), Bid, 3, Red);
      }
   }
   if (gi_276 == 1 && Ask <= gd_260) {
      for (l_pos_0 = 0; l_pos_0 < OrdersTotal(); l_pos_0++) {
         if (OrderSelect(l_pos_0, SELECT_BY_POS, MODE_TRADES) == FALSE) break;
         if (OrderSymbol() != Symbol()) continue;
         OrderClose(OrderTicket(), OrderLots(), Ask, 3, Red);
      }
   }
   if (gi_276 == -1 && g_price_220 + gi_128 <= TimeCurrent() && Bid > g_ask_244) {
      for (l_pos_0 = 0; l_pos_0 < OrdersTotal(); l_pos_0++) {
         if (OrderSelect(l_pos_0, SELECT_BY_POS, MODE_TRADES) == FALSE) break;
         if (OrderSymbol() != Symbol()) continue;
         OrderClose(OrderTicket(), OrderLots(), Bid, 3, Red);
         gd_unused_180 = TimeCurrent();
      }
   }
   if (gi_276 == 1 && g_price_220 + gi_128 <= TimeCurrent() && Bid < g_bid_252) {
      for (l_pos_0 = 0; l_pos_0 < OrdersTotal(); l_pos_0++) {
         if (OrderSelect(l_pos_0, SELECT_BY_POS, MODE_TRADES) == FALSE) break;
         if (OrderSymbol() != Symbol()) continue;
         OrderClose(OrderTicket(), OrderLots(), Ask, 3, Red);
         gd_unused_180 = TimeCurrent();
      }
   }
   if (gi_276 == -1 && g_price_220 + gi_132 <= TimeCurrent()) {
      for (l_pos_0 = 0; l_pos_0 < OrdersTotal(); l_pos_0++) {
         if (OrderSelect(l_pos_0, SELECT_BY_POS, MODE_TRADES) == FALSE) break;
         if (OrderSymbol() != Symbol()) continue;
         OrderClose(OrderTicket(), OrderLots(), Bid, 3, Red);
         gd_unused_180 = TimeCurrent();
      }
   }
   if (gi_276 == 1 && g_price_220 + gi_132 <= TimeCurrent()) {
      for (l_pos_0 = 0; l_pos_0 < OrdersTotal(); l_pos_0++) {
         if (OrderSelect(l_pos_0, SELECT_BY_POS, MODE_TRADES) == FALSE) break;
         if (OrderSymbol() != Symbol()) continue;
         OrderClose(OrderTicket(), OrderLots(), Ask, 3, Red);
         gd_unused_180 = TimeCurrent();
      }
   }
}